import * as React from 'react';
import { Redirect, RouteComponentProps, RouteProps, Route, Switch } from 'react-router-dom';
import { Container, Menu, Sidebar, Segment, Icon, Breadcrumb, Grid, Dropdown } from 'semantic-ui-react';
import { Header } from './Header';
import { Footer } from './Footer';
import TitleBarContainer from './TitleBarContainer';
import LeftMenu from './LeftMenu';

import ProbeDetail from '../../views/monitoring/probe/Detail';
import ProbeHost from '../../views/monitoring/probe/Host';
import ProbeHistory from '../../views/monitoring/probe/History';
import TargetList from '../../views/infrastructure/target/List';
import HistoryView from '../../views/history/List';

export interface Props extends RouteComponentProps<any> {
}
export interface State {
}

export class ProbeDetailLayout extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
    };
  }


  public render(): JSX.Element {
    const sub = [
      {
        'name': 'Info',
        'path': '/',
      },
      {
        'name': 'Host',
        'path': '/host',
      },
      {
        'name': 'History',
        'path': '/history',
      },
      {
        'name': 'Targets',
        'path': '/targets',
      },
    ];
    return (
      <Container fluid>
        <LeftMenu />
        <Segment basic style={{ margin: '0 0 0 210px', padding: '0' }}>
          <Header />
          <TitleBarContainer sub={sub} location={this.props.location.pathname} history={this.props.history}/>
          <Segment basic>
            <Switch>
              <Route exact={true} path={`${this.props.match.url}/:id`} component={ProbeDetail} />
              <Route exact={true} path={`${this.props.match.url}/:id/host`} component={ProbeHost} />
              <Route exact={true} path={`${this.props.match.url}/:id/history`} component={HistoryView} />
              <Route exact={true} path={`${this.props.match.url}/:id/targets`} component={TargetList} />
            </Switch>
          </Segment>
          <Footer />
        </Segment>
      </Container >
    );
  }
}


export default ProbeDetailLayout;

