import * as React from 'react';
import { RouteComponentProps, RouteProps, Route, Switch } from 'react-router-dom';
import { Container, Menu, Sidebar, Segment, Icon, Breadcrumb, Grid, Dropdown } from 'semantic-ui-react';
import { Header } from './Header';
import { Footer } from './Footer';
import TitleBarContainer from './TitleBarContainer';
import LeftMenu from './LeftMenu';
import SensorSetup from '../monitoring/sensor/Setup';
import SensorDetailInfo from '../monitoring/sensor/DetailInfo';
import SensorDetailItems from '../monitoring/sensor/DetailItems';
import SensorItemTree from '../monitoring/sensor/ItemTree';
import HistoryView from '../../views/history/List';

export interface Props extends RouteComponentProps<any> {
}
export interface State {
}

class SensorDetailLayout extends React.Component<Props, State> {

  public constructor(props?: Props, context?: State) {
    super(props, context);
    this.state = {
    };
  }

  public render(): JSX.Element {
    const sub = [
      {
        'name': 'Info',
        'path': '/',
      },
      {
        'name': 'Items',
        'path': '/items',
      },
      {
        'name': 'Setup',
        'path': '/setup',
      },
      {
        'name': 'History',
        'path': '/history',
      },
    ];
    return (
      <Container fluid>
        <LeftMenu />
        <Segment basic style={{ margin: '0 0 0 210px', padding: '0' }}>
          <Header />
          <TitleBarContainer sub={sub} location={this.props.location.pathname} history={this.props.history}/>
          {/*<TitleBar title='Sensor Details' sub={sub} />*/}
          <Segment basic>
            <Switch>
              <Route exact={true} path={`${this.props.match.url}/:id/`} component={SensorDetailInfo} />
              <Route exact={true} path={`${this.props.match.url}/:id/info`} component={SensorDetailInfo} />
              <Route exact={true} path={`${this.props.match.url}/:id/items`} component={SensorDetailItems} />
              {/*<Route path={`${this.props.match.url}/:id/history/`} component={EmailConfirm}/>*/}
              <Route exact={true} path={`${this.props.match.url}/:id/setup`} component={SensorSetup} />
              <Route exact={true} path={`${this.props.match.url}/setup`} component={SensorSetup} />
              <Route exact={true} path={`${this.props.match.url}/:id/tree`} component={SensorItemTree} />
              <Route exact={true} path={`${this.props.match.url}/:id/history`} component={HistoryView} />
            </Switch>
          </Segment>
          <Footer />
        </Segment>
      </Container >
    );
  }

}


export default SensorDetailLayout;
