import * as React from 'react';
import {
    Menu,
    Icon,
    Container,
} from 'semantic-ui-react';
import Page from '@overflow/commons/api/model/Page';

export interface Props {
    page: Page;
    onPageChange(pageNo: number): void;
}

export interface State {
    current: number;
}

export class Pager extends React.Component<Props, State> {

    constructor(props: Props, context: State) {
        super(props, context);
        this.state = {
            current: 0,
        };
    }

    public handlePaging = (pageNo: number) => {
        if (pageNo === this.state.current) {
            return;
        }
        this.setState({
            current: pageNo,
        });
        this.props.onPageChange(pageNo);
    }

    public handlePrevPage = (pn: string) => {
        let pageNo = 0;
        if (pn === 'P') {
            pageNo = this.state.current - 1;
        } else if (pn === 'N') {
            pageNo = this.state.current + 1;
        }
        this.setState({
            current: pageNo,
        });
        this.props.onPageChange(pageNo);
    }

    public renderPagination = (): JSX.Element => {
        let pageObj = this.props.page;

        if (pageObj === undefined) {
            return null;
        }
        let keyIdx = 0;
        let totalPage = pageObj.totalPages;
        let currPage = pageObj.number;
        let elems = new Array;
        let prevIndicator = pageObj.first ?
            <Menu.Item as='a' key={keyIdx} icon disabled><Icon name='left chevron' /></Menu.Item> :
            <Menu.Item as='a' key={keyIdx} icon onClick={this.handlePrevPage.bind(this, 'P')}>
                <Icon name='left chevron' />
            </Menu.Item>;
        elems.push(prevIndicator);
        for (let i = 0; i < totalPage; i++) {
            if (i === currPage) {
                elems.push(<Menu.Item key={++keyIdx} active as='a' onClick={this.handlePaging.bind(this, i)}><b>{i + 1}</b></Menu.Item>);
            } else {
                elems.push(<Menu.Item key={++keyIdx} as='a' onClick={this.handlePaging.bind(this, i)}>{i + 1}</Menu.Item>);
            }
        }
        let nextIndicator = pageObj.last ?
            <Menu.Item as='a' key={++keyIdx} icon disabled><Icon name='right chevron' /></Menu.Item> :
            <Menu.Item as='a' key={++keyIdx} icon onClick={this.handlePrevPage.bind(this, 'N')}>
                <Icon name='right chevron' />
            </Menu.Item>;
        elems.push(nextIndicator);

        return <Menu floated='right' pagination>
            {elems}
        </Menu>;
    }

    public render(): JSX.Element {
        return (
            <div>
                {this.renderPagination()}
            </div>
        );
    }
}
