
import * as React from 'react';
import {
  Table,
} from 'semantic-ui-react';


export interface Props {
  columnMap?: Map<string, string>;
  onHeaderColumnClick?(col:string, direction: string): void;
}

export interface State {
  column: string;
  colvalue: string;
  direction: 'ascending' | 'descending';
}


export class SortTableHeaderRow extends React.Component<Props, State> {

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      column: null,
      colvalue: null,
      direction: null,
    };
  }

  public render(): JSX.Element {
    return (
      <Table.Row>
        {this.renderCell()}
      </Table.Row>
    );
  }

  private renderCell = (): (JSX.Element | JSX.Element[]) => {
    let arr = [];
    let idx:number = 0;
    this.props.columnMap.forEach((val:string, key:string ) => {
      arr.push(
        <Table.HeaderCell key={idx++} textAlign={'center'}
                          sorted={this.state.column === key ? this.state.direction : null}
                          onClick={this.handleColumnSort(key)}>{key}</Table.HeaderCell>);
    });

    return arr;
  }

  private handleColumnSort = (col:string) => ():void => {
    if (this.state.column !== col) {
      this.setState({
        column: col,
        direction: 'ascending',
      });
    } else {
      this.setState({
        column: col,
        direction: this.state.direction === 'ascending' ? 'descending' : 'ascending',
      });
    }

    console.log(this.state.column);
    this.props.onHeaderColumnClick(this.props.columnMap.get(this.state.column), this.state.direction);

  }

}

