import { connect, Dispatch } from 'react-redux';
import {
  HistoryList,
  StateProps as HistoryStateProps,
  DispatchProps as HistoryDispatchProps,
  Props as HistoryProps,
} from './components/HistoryList';
import { push as routerPush } from 'react-router-redux';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';
import Domain from '@overflow/domain/api/model/Domain';
import Probe from '@overflow/probe/api/model/Probe';
import MetaHistoryType from '@overflow/meta/api/model/MetaHistoryType';
import * as readAllByProbeActions from '../redux/action/read_all_by_probe';
import * as readAllByProbeAndTypeActions from '../redux/action/read_all_by_probe_and_type';
import * as probeListActions from '@overflow/probe/redux/action/read_all_by_domain';
import * as historyTypeListActions from '@overflow/meta/redux/action/history_type_read_all';
import PageParams from '@overflow/commons/api/model/PageParams';


export function mapStateToProps(state: any, ownProps?: any): HistoryStateProps {
  return {
    path: ownProps.params,
    probes: state.probeList,
    histories: state.historyPage,
    historyTypes: state.historyTypes,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<HistoryDispatchProps>, ownProps?: HistoryDispatchProps): HistoryDispatchProps {
  return {
    onReadAllByDomain: (domain: Domain, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('HistoryService', 'readAllByDomain', readAllByProbeActions.REQUEST,
                                           JSON.stringify(domain), JSON.stringify(pageParams)));
    },
    onReadAllByProbe: (probe: Probe, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('HistoryService', 'readAllByProbe', readAllByProbeActions.REQUEST,
                                           JSON.stringify(probe), JSON.stringify(pageParams)));
    },
    onReadAllByProbeAndType: (probe: Probe, type: MetaHistoryType, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('HistoryService', 'readAllByProbeAndType', readAllByProbeAndTypeActions.REQUEST,
                                           JSON.stringify(probe), JSON.stringify(type), JSON.stringify(pageParams)));
    },
    onReadAllByDomainAndType: (domain: Domain, type: MetaHistoryType, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('HistoryService', 'readAllByProbeAndType', readAllByProbeAndTypeActions.REQUEST,
                                           JSON.stringify(domain), JSON.stringify(type), JSON.stringify(pageParams)));
    },
    onReadAllProbeByDomain: (domain: Domain) => {
      dispatch(asyncRequestActions.request('ProbeService', 'readAllByDomain', probeListActions.REQUEST, JSON.stringify(domain)));
    },
    onReadAllMetaHistoryType: () => {
      dispatch(asyncRequestActions.request('MetaHistoryTypeService', 'readAll', historyTypeListActions.REQUEST));
    },
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(HistoryList);
