import * as React from 'react';
import { Table, Button, Header, Container, Menu, Icon } from 'semantic-ui-react';
import { ListContainer } from '@overflow/commons/react/component/ListContainer';
import Probe from '@overflow/probe/api/model/Probe';
import Domain from '@overflow/domain/api/model/Domain';
import History from '@overflow/history/api/model/History';
import Page from '@overflow/commons/api/model/Page';
import MetaHistoryType from '@overflow/meta/api/model/MetaHistoryType';
import { Pager } from '@overflow/commons/react/component/Pager';
import { SortTableHeaderRow } from '@overflow/commons/react/component/SortTableHeaderRow';
import PageParams from '@overflow/commons/api/model/PageParams';

export interface StateProps {
  probes: Probe[];
  histories: Page;
  path: any;
  historyTypes: MetaHistoryType[];
}

export interface DispatchProps {
  onReadAllProbeByDomain?(domain: Domain): void;
  onReadAllMetaHistoryType?(): void;

  onReadAllByDomain?(domain: Domain, pageParams: PageParams): void;
  onReadAllByProbe?(probe: Probe, pageParams: PageParams): void;
  onReadAllByProbeAndType?(probe: Probe, type: MetaHistoryType, pageParams: PageParams): void;
  onReadAllByDomainAndType?(domain: Domain, type: MetaHistoryType, pageParams: PageParams): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
}

export class HistoryList extends React.Component<Props, State> {

  private selectedProbeId: number = 0;
  private isTypedHistory: boolean = false;

  private countPerPage: number = 10;
  private sortCol: string = 'id';
  private sortDirection: string = 'descending';
  private pageNo: number = 0;

  constructor(props: Props, context: State) {
    super(props, context);
  }

  public componentWillMount(): void {
    let domain: Domain = {
      id: 1,
    };
    this.props.onReadAllProbeByDomain(domain);
    // this.props.onReadAllMetaHistoryType();

    if (this.props.path === '/histories') {
      this.isTypedHistory = false;
      this.getAllHistory();
    } else {
      this.isTypedHistory = true;
      this.getTypedHistory();
    }
  }

  public getAllHistory(): void {
    const pageParams: PageParams = {
      pageNo: String(this.pageNo),
      countPerPage: String(this.countPerPage),
      sortCol: this.sortCol,
      sortDirection: this.sortDirection,
    };

    if (this.selectedProbeId === 0) {
      let domain: Domain = {
        id: 1,
      };
      this.props.onReadAllByDomain(domain, pageParams);
    } else {
      let probe: Probe = {
        id: this.selectedProbeId,
      };
      this.props.onReadAllByProbe(probe, pageParams);
    }
  }

  public getTypedHistory(): void {
    let url = this.props.path.split('/');
    let probe: Probe = {
      id: url[2],
    };
    const pageParams: PageParams = {
      pageNo: String(this.pageNo),
      countPerPage: String(this.countPerPage),
      sortCol: this.sortCol,
      sortDirection: this.sortDirection,
    };
    this.props.onReadAllByProbeAndType(probe, this.getMetaType(url[1]), pageParams);
  }

  public getMetaType(typeStr: string): MetaHistoryType {
    let metaType: MetaHistoryType = {
    };
    if (typeStr === 'member') {
      metaType.id = 1;
    } else if (typeStr === 'probe') {
      metaType.id = 2;
    } else if (typeStr === 'discovery') {
      metaType.id = 3;
    } else if (typeStr === 'target') {
      metaType.id = 4;
    } else if (typeStr === 'crawler') {
      metaType.id = 5;
    } else if (typeStr === 'sensor') {
      metaType.id = 6;
    }
    return metaType;
  }

  private handlePaging = (pageNo: number) => {
    let probe: Probe = {
      id: Number(1),
    };
    this.pageNo = pageNo;
    if (this.isTypedHistory) {
      this.getTypedHistory();
    } else {
      this.getAllHistory();
    }
  }

  private handleSort = (col: string, direction: string): void => {
    console.log(col + ' || direction:' + direction);
    this.sortCol = col;
    this.sortDirection = direction;
    if (this.isTypedHistory) {
      this.getTypedHistory();
    } else {
      this.getAllHistory();
    }
  }

  public render(): JSX.Element {
    // let cols:string[] = ['No.', 'Probe', 'Type', 'Message', 'Created At', 'Created By'];
    let colsmap: Map<string, string> = new Map();
    colsmap.set('No.', 'id');
    colsmap.set('Probe', 'probe.displayName');
    colsmap.set('Type', 'type.name');
    colsmap.set('Message', 'message');
    colsmap.set('Created At', 'createDate');
    colsmap.set('Created By', 'member.name');

    let historyList: JSX.Element = (
      <Container fluid>
        <Table celled selectable striped sortable fixed>
          <Table.Header>
            <SortTableHeaderRow columnMap={colsmap} onHeaderColumnClick={this.handleSort} />
            {/*<Table.Row>*/}
            {/*<Table.HeaderCell textAlign={'center'}>No.</Table.HeaderCell>*/}
            {/*<Table.HeaderCell textAlign={'center'}>Probe</Table.HeaderCell>*/}
            {/*<Table.HeaderCell textAlign={'center'}>Type</Table.HeaderCell>*/}
            {/*<Table.HeaderCell textAlign={'center'}>Message</Table.HeaderCell>*/}
            {/*<Table.HeaderCell textAlign={'center'}>Created At</Table.HeaderCell>*/}
            {/*<Table.HeaderCell textAlign={'center'}>Created By</Table.HeaderCell>*/}
            {/*</Table.Row>*/}
          </Table.Header>

          <Table.Body>
            {this.props.histories && this.props.histories.content ?
              this.props.histories.content.map((history: History, index: number) => (
                <Table.Row key={index} >
                  <Table.Cell textAlign={'center'}>{history.id}</Table.Cell>
                  <Table.Cell >
                    {history.probe.displayName}
                  </Table.Cell>
                  <Table.Cell textAlign={'center'}>
                    {history.type.name}
                  </Table.Cell>
                  <Table.Cell>
                    {history.message}
                  </Table.Cell>
                  <Table.Cell>
                    {history.createDate}
                  </Table.Cell>
                  <Table.Cell>
                    {history.member.name}
                  </Table.Cell>
                </Table.Row>
              )) : ''}
          </Table.Body>
          <Table.Footer>
            <Table.Row>
              <Table.HeaderCell colSpan='6' textAlign='center'>
                <Pager page={this.props.histories} onPageChange={this.handlePaging} />
              </Table.HeaderCell>
            </Table.Row>
          </Table.Footer>
        </Table>
      </Container>
    );

    let filter = null;
    if (!this.isTypedHistory) {
      filter = <HistoryFilter probes={this.props.probes}
        onProbeChange={this.handleProbeChange}
      />;
    }
    return (
      <ListContainer
        filter={filter}
        contents={historyList}
        data={this.props.histories}
      />
    );
  }

  private handleProbeChange = (probeId: number) => {
    this.selectedProbeId = probeId;
    this.getAllHistory();
  }

}




export interface FilterProps {
  probes: Probe[];
  onProbeChange(probeId: number): void;
}

export interface FilterState {
  selectedProbeId: number;
}

import { Dropdown, Form, Radio } from 'semantic-ui-react';

export class HistoryFilter extends React.Component<FilterProps, FilterState> {

  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      selectedProbeId: 0,
    };
  }

  public render(): JSX.Element {
    if (this.props.probes === null || this.props.probes === undefined) {
      return null;
    }
    return (
      <Form>
        <Form.Field>Probe</Form.Field>
        <Form.Field>
          <Dropdown selection placeholder='All' options={this.getOptions()}
            onChange={(event: React.SyntheticEvent<HTMLElement>, data: any) => {
              this.setState({
                selectedProbeId: data.value,
              });
              this.props.onProbeChange(data.value);
            }} />
        </Form.Field>
      </Form>
    );
  }

  private getOptions(): Array<object> {
    let res = new Array;
    let all = {
      key: 0,
      text: 'All',
      value: 0,
    };
    res.push(all);
    this.props.probes.map((probe: Probe, index: number) => {
      let option = {
        key: index + 1,
        text: probe.displayName,
        value: probe.id,
      };
      res.push(option);
    });
    return res;
  }
}
