
import * as React from 'react';
import { Icon, Step, Button, Table, Radio, Form, Container, Checkbox } from 'semantic-ui-react';
import { Grid, Image, Label, Segment, Dropdown, Input, List, Accordion, Loader, DropdownItemProps, DropdownProps } from 'semantic-ui-react';

import MetaCrawler from '../../api/model/MetaCrawler';

import SensorItemTree from '@overflow/meta/react/SensorItemTree';
import CrawlerAuthInputsContainer from '../CrawlerAuthInputs';
import MetaCrawlerInputItem from '@overflow/meta/api/model/MetaCrawlerInputItem';

import Target from '@overflow/target/api/model/Target';
import SensorRegistInfo from '@overflow/sensor/api/model/SensorRegistInfo';

export interface CrawlerSelectorStateProps {
  metaCralwerList?: MetaCrawler[];
  targetId?: number;
  metaCrawlerInputItemList?: MetaCrawlerInputItem[];
  onSelectCrawlerId?(id: number): void;
  setSensor?(data: SensorRegistInfo): void;
  getSensor?(): SensorRegistInfo;
}

export interface CrawlerSelectorDispatchProps {
  onCrawlerReadAllByTarget?(target: Target): void;
  onCrawlerReadAllByMetaCrawler?(crawler: MetaCrawler): void;

}

export type CrawlerSelectorProps = CrawlerSelectorStateProps & CrawlerSelectorDispatchProps;

export interface CrawlerSelectorState {
  isInstalling: boolean;
  selected: MetaCrawler;
  // selectOptions: Array<DropdownItemProps>;
}

export class CrawlerSelector extends React.Component<CrawlerSelectorProps, CrawlerSelectorState> {

  private selectOptions: Array<DropdownItemProps>;

  constructor(props: CrawlerSelectorProps, context: CrawlerSelectorState) {
    super(props, context);
    this.state = {
      selected: null,
      isInstalling: false,
    };

    let target: Target;
    if (this.props.targetId === undefined) {
      target = null;
    } else {
      target = { id: this.props.targetId };
    }
    this.selectOptions = [];
    this.props.onCrawlerReadAllByTarget(target);

  }

  // public componentWillMount(): void {
  //   this.getMetaCrawlers();
  // }

  public convertCrawler(): void {

    let crawlerOptions = [];
    let crawler: MetaCrawler;
    for (crawler of this.props.metaCralwerList) {
      let option = {
        // key: crawler.id,
        text: crawler.name,
        value: JSON.stringify(crawler),
        icon: 'check', // or close?
      };
      crawlerOptions.push(option);
    }

    this.selectOptions = crawlerOptions;
  }

  public handleCrawlerSelection(event: React.SyntheticEvent<HTMLElement>, data: DropdownProps): void {
    // this.setState({
    //   selected: data.key,
    // });
    this.checkInstall();

    let vCrawler: MetaCrawler = JSON.parse(String(data.value));

    let crawler: MetaCrawler = {
      id: vCrawler.id,
    };
    this.props.onCrawlerReadAllByMetaCrawler(crawler);

    this.props.onSelectCrawlerId(vCrawler.id);

    let sd = this.props.getSensor();
    sd.crawler = vCrawler;
    this.props.setSensor(sd);
  }

  public checkInstall(): void {
    // this.setState({
    //   isInstalling: true,
    // });
    // let that = this;
    // setInterval(() => {
    //   this.setState({
    //     isInstalling: false,
    //   });
    // },          1500);
  }

  public renderCrawler(): JSX.Element {

    if (this.props.metaCralwerList === undefined) {
      return null;
    }

    this.convertCrawler();
    console.log(this.selectOptions);

    return (
      <Grid.Row>
        <Grid.Column width='4'>
          <Dropdown openOnFocus
            placeholder='Select Crawler' selection options={this.selectOptions} onChange={this.handleCrawlerSelection.bind(this)} />
          <br />
          <br />
        </Grid.Column>
        <Grid.Column>
          <CrawlerAuthInputsContainer metaCrawlerInputItemList={this.props.metaCrawlerInputItemList} />
        </Grid.Column>
      </Grid.Row>
    );
  }

  public render(): JSX.Element {

    return (
      <Segment vertical>
        <Loader active={this.state.isInstalling} size='large' >Installing the Crawler</Loader>
        <Icon name='checkmark' /> Choose a Crawler type.
        <br />
        <br />
        <Grid>
          {this.props.metaCralwerList ? this.renderCrawler() : ''}
        </Grid>
      </Segment>
    );
  }
}
