import * as React from 'react';
import * as _ from 'lodash';
// import update from 'immutability-helper';

import {
  Checkbox,
  Container,
  Label,
  Accordion,
  Icon,
  List, Button,
  ListItemProps,
  CheckboxProps,
} from 'semantic-ui-react';


import MetaSensorItemType from '../../api/model/MetaSensorItemType';
import MetaSensorItem from '../../api/model/MetaSensorItem';

import Sensor from '@overflow/sensor/api/model/Sensor';
import SensorItem from '@overflow/sensor/api/model/SensorItem';

import * as Utils from '@overflow/commons/util/Utils';
import SensorRegistInfo from '@overflow/sensor/api/model/SensorRegistInfo';

export interface SensorItemTreeStateProps {
  crawlerId?: number;
  sensorItemList?: SensorItem[];
  metaSensorItemTypeList?: MetaSensorItemType[];
  metaSensorItemList?: MetaSensorItem[];
  setSensor?(data: SensorRegistInfo): void;
  getSensor?(): SensorRegistInfo;
}

export interface SensorItemTreeDispatchProps {
  onReadAllBySensor?(sensor: Sensor): void;
  onSensorItemTypeReadAll?(): void;
  onReadAll?(): void;
}


export type SensorItemTreeProps = SensorItemTreeStateProps & SensorItemTreeDispatchProps;


export interface SensorItemTreeState {
  categoryState: Map<number, boolean>;
  categoryCheckState: Map<number, boolean>;
  itemState: Map<number, Array<boolean>>;

}

interface TreeItem {
  metaSensorItemList: Array<MetaSensorItem>;
  metaSensorItemType: MetaSensorItemType;
}

export class SensorItemTree extends React.Component<SensorItemTreeProps, SensorItemTreeState> {

  private itemMap: Map<number, TreeItem>;
  private selectedItemMap: Map<number, Array<MetaSensorItem>>;

  constructor(props: any, context: any) {
    super(props, context);

    this.itemMap = new Map;
    this.selectedItemMap = new Map,

      this.state = {
        categoryState: new Map(),
        categoryCheckState: new Map(),
        itemState: new Map(),
      };


    this.props.onReadAll();
    this.props.onSensorItemTypeReadAll();
    // fs.readFile('../../../../../dh.json', this.handlJSONFile);
  }





  public ViewSensorItemType(): JSX.Element[] {

    if(this.props.metaSensorItemTypeList === undefined
    || this.props.metaSensorItemList === undefined) {
      return null;
    }

    this.sortItemMap();

    let elems: JSX.Element[] = new Array();

    this.itemMap.forEach((data: TreeItem, key: number) => {
      // this.state.itemState[key] = new Array(data.metaSensorItemList.length).fill(false);
      elems.push(
        <List.Item key={key} >
          <List.Icon name={this.state.categoryState[key] ? 'chevron up' : 'chevron down'}
            onClick={this.onTypeClick.bind(this, key)} />
          <List.Content>
            <List.Header>
              <Checkbox label={data.metaSensorItemType.name} checked={this.state.categoryCheckState[key]} onChange={
                (event: React.FormEvent<HTMLInputElement>, checkProps: CheckboxProps) => {
                  this.onTypeCheckCBox(key, checkProps, data);
                }} />
            </List.Header>
            <List.Description style={{ marginLeft: '26px' }}>Category</List.Description>
            {this.state.categoryState[key] ? this.ViewSensorItem(data.metaSensorItemList, key) : ''}
          </List.Content>
        </List.Item>,
      );
    });

    return elems;
  }



  public ViewSensorItem(metaSensorItemList: MetaSensorItem[], parentKey: number): JSX.Element[] {
    let elems: JSX.Element[] = new Array();

    if (this.state.itemState[parentKey] === undefined) {
      this.state.itemState[parentKey] = new Array(metaSensorItemList.length).fill(false);
    }

    metaSensorItemList.map((item: MetaSensorItem, idx: number) => {
      elems.push(
        <List.List key={String(parentKey) + String(idx)} onClick={this.onItemClick.bind(this, parentKey, idx)}>
          <List.Item >
            <List.Icon name='file' />
            <List.Content>
              <List.Header> <Checkbox label={item.name} checked={this.state.itemState[parentKey][idx]} onChange={
                (event: React.FormEvent<HTMLInputElement>, checkProps: CheckboxProps) => {
                  this.onItemCheckCBox(parentKey, checkProps, item);
                }} /></List.Header>
              <List.Description style={{ marginLeft: '26px' }}>Sensor Item</List.Description>
            </List.Content>
          </List.Item>
        </List.List>,
      );
    });

    return elems;
  }

  public render(): JSX.Element {
    return (
      <Container fluid>
        <List selection>
          {this.ViewSensorItemType()}
        </List>
        {/*<Button primary floated='right' onClick={() => {
          console.log(this.selectedItemMap);
        }}>Test</Button><br /><br />*/}
      </Container>
    );
  }

  private sortItemMap(): void {

    if(this.itemMap.size > 0) {
      return;
    }

    for(let si of this.props.metaSensorItemList) {
      let sensorItem: MetaSensorItem = si;

      if (this.itemMap.has(sensorItem.itemType.id)) {
        this.itemMap.get(sensorItem.itemType.id).metaSensorItemList.push(sensorItem);
      } else {
        let item: TreeItem = { metaSensorItemList: null, metaSensorItemType: null };
        item.metaSensorItemList = [];
        item.metaSensorItemList.push(sensorItem);
        item.metaSensorItemType = this.GetMetaSensorItemType(sensorItem.itemType.id);
        this.itemMap.set(sensorItem.itemType.id, item);
      }
    }

  }

  private onItemClick = (parentKey: number, idx: number) => {
    let newItemState: Map<number, Array<boolean>> = _.clone(this.state.itemState);
    newItemState[parentKey][idx] = !newItemState[parentKey][idx];
    this.setState({ itemState: newItemState });
  }

  private onItemCheckCBox = (parentKey: number, checkProps: CheckboxProps, item: MetaSensorItem) => {
    if (this.selectedItemMap.get(parentKey) === undefined) {
      this.selectedItemMap.set(parentKey, []);
    }
    if (checkProps.checked) {
      this.selectedItemMap.get(parentKey).push(item);
    } else {
      let index: number = this.selectedItemMap.get(parentKey).indexOf(item);
      if (index >= 0) {
        this.selectedItemMap.get(parentKey).splice(index, 1);
      }
      if (this.selectedItemMap.get(parentKey).length <= 0) {
        let newCheckState: Map<number, boolean> = _.clone(this.state.categoryCheckState);
        newCheckState[parentKey] = false;
        this.setState({ categoryCheckState: newCheckState });
      }
    }
    let sd = this.props.getSensor();
    sd.sensorItemMap = this.selectedItemMap;
    this.props.setSensor(sd);
  }

  private onTypeClick = (key: number) => {
    let newCategoryState: Map<number, boolean> = _.clone(this.state.categoryState);
    newCategoryState[key] = !newCategoryState[key];
    this.setState({ categoryState: newCategoryState });
  }

  private onTypeCheckCBox = (key: number, checkProps: CheckboxProps, data: TreeItem) => {
    this.state.categoryCheckState[key] = checkProps.checked;
    let newItemState: Map<number, Array<boolean>> = _.clone(this.state.itemState);
    if (newItemState[key] === undefined) {
      newItemState[key] = new Array(data.metaSensorItemList.length).fill(false);
    }
    newItemState[key].fill(checkProps.checked);
    if (checkProps.checked) {
      this.selectedItemMap.set(key, _.clone(data.metaSensorItemList));
    } else {
      this.selectedItemMap.get(key).length = 0;
    }
    this.setState({ itemState: newItemState });

    let sd = this.props.getSensor();
    sd.sensorItemMap = this.selectedItemMap;
    this.props.setSensor(sd);
  }

  private checkUnCheckParent(metaSensorItemList: Array<MetaSensorItem>): boolean {
    if (metaSensorItemList.length <= 0) {
      return true;
    }
    return false;
  }

  private GetMetaSensorItemType(id: number): MetaSensorItemType {

    for(let sit of this.props.metaSensorItemTypeList) {
      if(sit.id === id) {
        return sit;
      }
    }

    // for (let i: number = 0; i < SensorTypeJsonData.length; ++i) {
    //   let msit: MetaSensorItemType = SensorTypeJsonData[i];
    //   if (msit.id === id) {
    //     return msit;
    //   }
    // }
    return null;
  }

}

export default SensorItemTree;
