import * as React from 'react';
import {
    Container,
    List,
    Header,
} from 'semantic-ui-react';
import Page from '@overflow/commons/api/model/Page';
import Member from '@overflow/member/api/model/Member';
import Notification from '../../api/model/Notification';
import PageParams from '@overflow/commons/api/model/PageParams';

export interface StateProps {
    notifications: Page;
}

export interface DispatchProps {
    onReadTop5Unconfirmed(member: Member, pageParams: PageParams): void;
    onRedirectAllNotifications(): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
    show: boolean;
}

export class NotificationModal extends React.Component<Props, State> {

    private countPerPage: number = 5;
    constructor(props: Props, context: State) {
        super(props, context);
        this.state = {
            show: true,
        };
    }
    public componentWillMount(): void {
        const member: Member = {
            id: 1,
        };
        const pageParams: PageParams = {
            sortCol: 'id',
            sortDirection: 'descending',
            countPerPage: String(this.countPerPage),
            pageNo: String(0),
        };
        this.props.onReadTop5Unconfirmed(member, pageParams);
    }

    public renderItems(): (JSX.Element | JSX.Element[]) {
        if (this.props.notifications === undefined || this.props.notifications.content.length === 0) {
            return <div>No user notifications found. </div>;
        }
        return this.props.notifications.content.map((item: Notification, index: number) => (
            <List.Item key={index}>
                <List.Icon name='bell outline' size='large' verticalAlign='middle' />
                <List.Content>
                    <List.Header >{item.title}</List.Header>
                    <List.Description >{item.message}</List.Description>
                </List.Content>
            </List.Item>
        ));
    }

    public render(): JSX.Element {
        if(!this.state.show) {
            return null;
        }

        return (
            <Container fluid>
                <Header as='h4' content='User Notifications' />
                <List divided relaxed>
                    {this.renderItems()}
                    <List.Item onClick={this.handleViewAll}>
                        <List.Content>
                            <List.Description as='a'><b>View All</b></List.Description>
                        </List.Content>
                    </List.Item>
                </List>
            </Container>
        );
    }

    private handleViewAll = (): void => {
        this.setState({
            show: false,
        });
        this.props.onRedirectAllNotifications();
    }
}
