import * as React from 'react';
import {
    Container,
    Table,
} from 'semantic-ui-react';
import Page from '@overflow/commons/api/model/Page';
import Member from '@overflow/member/api/model/Member';
import Notification from '../../api/model/Notification';
import { SortTableHeaderRow } from '@overflow/commons/react/component/SortTableHeaderRow';
import { Pager } from '@overflow/commons/react/component/Pager';
import PageParams from '@overflow/commons/api/model/PageParams';

export interface StateProps {
    notiPage: Page;
}

export interface DispatchProps {
    onReadAll(member: Member, pageParams: PageParams): void;
}

export type Props = StateProps & DispatchProps;

export interface State {
}

export class NotificationList extends React.Component<Props, State> {

    private countPerPage: number = 10;
    private sortCol: string = 'id';
    private sortDirection: string = 'descending';
    private pageNo: number = 0;

    constructor(props: Props, context: State) {
        super(props, context);
        this.state = {
        };
    }
    public componentWillMount(): void {
        this.getData();
    }

    private getData(): void {
        const member = {
            id: 1,
        };
        const pageParams: PageParams = {
            sortCol: this.sortCol,
            sortDirection: this.sortDirection,
            countPerPage: String(this.countPerPage),
            pageNo: String(this.pageNo),
        };
        this.props.onReadAll(member, pageParams);
    }

    public renderItems(): (JSX.Element | JSX.Element[]) {
        if (this.props.notiPage === undefined || this.props.notiPage.content.length === 0) {
            return <div>No user notifications found. </div>;
        }
        return this.props.notiPage.content.map((noti: Notification, index: number) => (
            <Table.Row key={index} active={this.checkRead(noti)}>
                <Table.Cell textAlign={'center'} collapsing>{noti.id}</Table.Cell>
                <Table.Cell textAlign={'center'} collapsing>{noti.createDate}</Table.Cell>
                <Table.Cell textAlign={'center'} collapsing>{noti.title}</Table.Cell>
                <Table.Cell textAlign={'center'}>{noti.message}</Table.Cell>
            </Table.Row>
        ));
    }

    public render(): JSX.Element {
        let colsmap: Map<string, string> = new Map();
        colsmap.set('No.', 'id');
        colsmap.set('Created At', 'createDate');
        colsmap.set('Title', 'title');
        colsmap.set('Message', 'message');

        return (
            <Container fluid>
                <Table  sortable>
                    <Table.Header>
                        <SortTableHeaderRow columnMap={colsmap} onHeaderColumnClick={this.handleSort} />
                    </Table.Header>

                    <Table.Body>
                        {this.renderItems()}
                    </Table.Body>
                    <Table.Footer>
                        <Table.Row>
                            <Table.HeaderCell colSpan='4'>
                                <Pager page={this.props.notiPage} onPageChange={this.handlePaging} />
                            </Table.HeaderCell>
                        </Table.Row>
                    </Table.Footer>
                </Table>
            </Container>
        );
    }

    private handleSelect = (selected: Notification) => {
        console.log('handleSelect');
    }
    private handleSort = (col: string, direction: string) => {
        this.sortCol = col;
        this.sortDirection = direction;
        this.getData();
    }
    private handlePaging = (pageNo: number) => {
        this.pageNo = pageNo;
        this.getData();
    }
    private checkRead = (noti: Notification): boolean => {
        if (noti.confirmDate === null) {
            return true;
        }
        return false;
    }
}
