import { connect, Dispatch } from 'react-redux';
import { push as routerPush } from 'react-router-redux';

import {
  SensorList,
  StateProps as SensorListStateProps,
  DispatchProps as SensorListDispatchProps,
} from './components/SensorList';
import State from '../redux/state/ReadAllByTarget';
import * as ReadAllByTargetActions from '../redux/action/read_all_by_target';
import * as ReadAllByProbeActions from '../redux/action/read_all_by_probe';
import * as ReadAllByDomainActions from '../redux/action/read_all_by_domain';
import * as ReadAllByInfraActions from '../redux/action/read_all_by_infra';
import Target from '@overflow/target/api/model/Target';
import Sensor from '@overflow/sensor/api/model/Sensor';
import Probe from '@overflow/probe/api/model/Probe';
import Domain from '@overflow/domain/api/model/Domain';
import Infra from '@overflow/infra/api/model/Infra';
import PageParams from '@overflow/commons/api/model/PageParams';

import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';

export function mapStateToProps(state: any, props: any): SensorListStateProps {
  return {
    sensorList: state.SensorList,
    infraId: props.params.id,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): SensorListDispatchProps {
  return {
    onReadAllByInfra: (infraId: number, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('SensorService', 'readAllByInfra',
                                           ReadAllByInfraActions.REQUEST, infraId, JSON.stringify(pageParams)));
    },
    onReadAllByDomain: (domain: Domain, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('SensorService', 'readAllByDomain',
                                           ReadAllByDomainActions.REQUEST, JSON.stringify(domain), JSON.stringify(pageParams)));
    },
    onReadAllByProbe: (probe: Probe) => {
      dispatch(ReadAllByProbeActions.request(probe));
    },
    onSelectSensor: (id: number) => {
      dispatch(routerPush('/sensor/' + String(id)));
    },
    onAddSensor: (infraId: string) => {
      dispatch(routerPush('/sensor_setup/' + infraId));
    },
  };
}


export default connect(mapStateToProps, mapDispatchToProps)(SensorList);
