import * as React from 'react';
import {
  Icon,
  Step,
  Button,
  Table,
  Radio,
  Form,
  Container,
  Checkbox,
} from 'semantic-ui-react';
import {
  Grid,
  Image,
  Label,
  Segment,
  Dropdown,
  Input,
  List,
  Accordion,
  Loader,
  DropdownItemProps, DropdownProps,
} from 'semantic-ui-react';

import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';
import Infra from '@overflow/infra/api/model/Infra';
import Domain from '@overflow/domain/api/model/Domain';

import Page from '@overflow/commons/api/model/Page';
import SensorRegistInfo from '../../api/model/SensorRegistInfo';
import Sensor from '../../api/model/Sensor';
import SensorItem from '../../api/model/SensorItem';
import MetaSensorItem from '@overflow/meta/api/model/MetaSensorItem';
import SensorItemTree from '@overflow/meta/react/SensorItemTree';
import CrawlerSelectorContainer from '@overflow/meta/react/CrawlerSelector';

import { MetaSensorStatus_ID } from '@overflow/meta/api/model/MetaSensorStatus';


export interface SensorConfigStepperStateProps {
  steps?: Array<JSX.Element>;
  infraList?: Page;
  infra?: Infra;
  infraId?: number;
  setSensor?(data: SensorRegistInfo): void;
  getSensor?(): SensorRegistInfo;
}

export interface SensorConfigStepperDispatchProps {
  onRegistSensorConfig?(sensor: Sensor, sensorItemList: SensorItem[]): void;
  onMoveSensors?(): void;
  onMoveTargetSensors?(targetId: number): void;
}

export type SensorConfigStepperProps = SensorConfigStepperStateProps & SensorConfigStepperDispatchProps;

export interface SensorConfigStepperState {
  currentStep: number;
}

export class SensorConfigStepper extends React.Component<SensorConfigStepperProps, SensorConfigStepperState> {

  private selectOptions: Array<DropdownItemProps>;

  constructor(props: SensorConfigStepperProps, context: SensorConfigStepperState) {
    super(props, context);
    this.state = {
      currentStep: 1,
    };
  }



  public handleActive(idx: number): boolean {
    if (this.state.currentStep === idx) {
      return true;
    }
    return false;
  }

  public handleCompleted(idx: number): boolean {
    if (this.state.currentStep > idx) {
      return true;
    }
    return false;
  }

  public handlePrev(event: React.SyntheticEvent<HTMLAnchorElement>, data: object): void {
    let step: number = this.state.currentStep;
    if (step <= 1) {
      step = 1;
    } else {
      step--;
    }
    this.setState({
      currentStep: step,
    });
  }
  public handleNext(event: React.SyntheticEvent<HTMLAnchorElement>, data: object): void {
    let step: number = this.state.currentStep;

    let errorStr: string = this.checkSensorData();
    if (errorStr.length > 0) {
      alert('Choose ' + errorStr);
      return;
    }

    if (step >= this.props.steps.length + 1) {
      step = this.props.steps.length + 1;
    } else {
      step++;
    }
    this.setState({
      currentStep: step,
    });
    if (step === this.props.steps.length + 1) {
      console.log('Done');
      console.log(this.props.getSensor());
      this.registSensor();
      if (this.props.infraId === undefined) {
        this.props.onMoveSensors();
      } else {
        this.props.onMoveTargetSensors(this.props.infraId);
      }

    }
  }

  public checkSensorData(): string {

    let sd = this.props.getSensor();

    switch (this.state.currentStep) {
      case 1:
        {
          if (sd.infra === undefined || sd.infra === null) {
            return 'Target';
          }
          if (sd.crawler === undefined || sd.crawler === null) {
            return 'Crawler';
          }
        }
        break;
      case 2:
        {
          if (sd.sensorItemMap === undefined || sd.sensorItemMap === null || this.checkItemMapSize() === false) {
            return 'Sensor Item';
          }
        }
        break;
      case 3:
        {
          if (sd.interval === undefined) {
            return 'Interval';
          }
        }
        break;
      default:
        break;
    }

    return '';
  }

  public checkItemMapSize(): boolean {


    if (this.props.getSensor().sensorItemMap.size <= 0) {
      return false;
    }

    let result: boolean = false;

    this.props.getSensor().sensorItemMap.forEach((value: MetaSensorItem[], key: number) => {
      if (value.length > 0) {
        result = true;
      }
    });

    return result;
  }

  public registSensor(): void {
    let sensorData = this.props.getSensor();
    let sensor: Sensor = {};

    sensor.crawler = { id: sensorData.crawler.id };
    sensor.target = { id: sensorData.infra.target.id };
    sensor.status = { id: MetaSensorStatus_ID.RUNNING };
    sensor.description = sensorData.infra.infraType.name + '-' + sensorData.crawler.name;

    let siList: Array<SensorItem> = new Array;

    sensorData.sensorItemMap.forEach((value: MetaSensorItem[], key: number) => {
      for (let msi of value) {
        siList.push({
          item: { id: msi.id },
        });
      }
    });

    console.log(sensor);
    console.log(siList);

    this.props.onRegistSensorConfig(sensor, siList);
  }

  public showContent(): any {
    return this.props.steps[this.state.currentStep - 1];
  }

  public checkPrevDisabled(): boolean {
    if (this.state.currentStep <= 1) {
      return true;
    } else {
      return false;
    }
  }

  public checkNextDisabled(): boolean {
    if (this.state.currentStep === this.props.steps.length + 1) {
      return true;
    } else {
      return false;
    }
  }

  public convertInfraList(): void {

    if (this.props.infraList === undefined) {
      return null;
    }

    let selectionOptions: Array<DropdownItemProps> = new Array;

    for (let infra of this.props.infraList.content) {

      selectionOptions.push(this.createOption(infra));

    }
    this.selectOptions = selectionOptions;
  }

  public convertInfra(): void {
    if (this.props.infra === undefined) {
      return;
    }
    let selectionOptions: Array<DropdownItemProps> = new Array;

    selectionOptions.push(this.createOption(this.props.infra));
    this.selectOptions = selectionOptions;

    let sd = this.props.getSensor();
    // sd.targetId = this.props.infra.target.id;
    // sd.type = this.props.infra.infraType.name;
    sd.infra = this.props.infra;
    this.props.setSensor(sd);
  }

  public createOption(infra: Infra): DropdownItemProps {
    let option = {
      key: infra.id,
      text: infra.infraType.name + '-' + infra.target.displayName,
      // value: infra.target.id,
      value: JSON.stringify(infra),
      // icon: 'check', // or close?
    };
    return option;
  }

  public defaultValue(): any {
    if (this.selectOptions !== undefined && this.selectOptions.length > 0) {
      return this.selectOptions[0].value;
    }
    return null;
  }

  public onChangeTarget(event: React.SyntheticEvent<HTMLElement>, data: DropdownProps): void {
    let sd = this.props.getSensor();
    // let infra: Infra = JSON.parse(String(data.value));
    // sd.targetId = infra.target.id;
    // sd.type = infra.infraType.name;
    sd.infra = JSON.parse(String(data.value));
    this.props.setSensor(sd);
  }

  public renderInfra(): JSX.Element {

    if (this.props.infraId === undefined) {
      this.convertInfraList();
    } else {
      this.convertInfra();
    }

    return (<Dropdown
      placeholder='Select Target' selection options={this.selectOptions} defaultValue={this.defaultValue()}
      onChange={this.onChangeTarget.bind(this)} />);
  }

  public render(): JSX.Element {

    return (
      <Container fluid>
        <Step.Group fluid>
          <Step active={this.handleActive(1)} completed={this.handleCompleted(1)}>
            <Icon name='settings' color='grey' />
            <Step.Content title='Step 1' description='골라골라 크롤러를 골라' />
          </Step>

          <Step active={this.handleActive(2)} completed={this.handleCompleted(2)}>
            <Icon name='list ul' color='grey' />
            <Step.Content title='Step 2' description='골라골라 아이템도 골라' />
          </Step>

          <Step active={this.handleActive(3)} completed={this.handleCompleted(3)}>
            <Icon name='options' color='grey' />
            <Step.Content title='Step 3' description='나머지도 골라 아 빨리' />
          </Step>
        </Step.Group>
        {this.renderInfra()}
        {this.showContent()}
        <br />
        <Button.Group floated='right'> {/* floated 사용시 레이아웃 깨지는 현상 */}
          <Button content='Prev' icon='left arrow' labelPosition='left'
            onClick={this.handlePrev.bind(this)} disabled={this.checkPrevDisabled()} />
          <Button.Or />
          <Button content={this.state.currentStep === 3 ? 'Finish' : 'Next'}
            icon={this.state.currentStep === 3 ? 'send' : 'right arrow'} labelPosition='right' positive
            onClick={this.handleNext.bind(this)} disabled={this.checkNextDisabled()} />
        </Button.Group>
      </Container>
    );
  }
}
