import * as React from 'react';
import {
  Icon,
  Step,
  Button,
  Table,
  Radio,
  Form,
  Container,
  Checkbox,
} from 'semantic-ui-react';
import {
  Grid,
  Image,
  Label,
  Segment,
  Dropdown,
  Input,
  List,
  Accordion,
  Loader,
  DropdownItemProps, DropdownProps,
} from 'semantic-ui-react';

import MetaCrawler from '@overflow/meta/api/model/MetaCrawler';
import Infra from '@overflow/infra/api/model/Infra';
import Domain from '@overflow/domain/api/model/Domain';

import Page from '@overflow/commons/api/model/Page';
import SensorRegistInfo from '../../api/model/SensorRegistInfo';

import SensorItemTree from '@overflow/meta/react/SensorItemTree';
import CrawlerSelectorContainer from '@overflow/meta/react/CrawlerSelector';

import SensorConfigStepperContainer from '../SensorConfigStepper';

export interface SensorConfigurationStateProps {
  infraId?: number;
  infraList?: Page;
  infra?: Infra;
}

export interface SensorConfigurationDispatchProps {
  onReadAllTargetByDomain?(domain: Domain): void;
  onReadInfra?(infraId: number): void;
}

export interface SensorConfigurationState {
  selectedCrawlerId: number;
}

export type SensorConfigurationProps = SensorConfigurationStateProps & SensorConfigurationDispatchProps;

export class SensorConfiguration extends React.Component<SensorConfigurationProps, SensorConfigurationState> {

  private sensorData: any;

  constructor(props: SensorConfigurationProps, context: SensorConfigurationState) {
    super(props, context);
    this.state = {
      selectedCrawlerId: 0,
    };
    this.sensorData = {};
  }

  public componentWillMount(): void {
    if (this.props.infraId === undefined) {
      this.props.onReadAllTargetByDomain({ id: 1 });
    } else {
      this.props.onReadInfra(this.props.infraId);
    }
  }

  public onSelectCrawlerId = (id: number) => {
    this.setState({
      selectedCrawlerId: id,
    });
  }

  public setSensor = (data: SensorRegistInfo) => {
    this.sensorData = data;
  }

  public getSensor = () => {
    return this.sensorData;
  }


  public render(): JSX.Element {
    let steps = [
      <CrawlerSelectorContainer onSelectCrawlerId={this.onSelectCrawlerId.bind(this)}
        setSensor={this.setSensor.bind(this)} getSensor={this.getSensor.bind(this)} />,
      <Segment vertical>
        <SensorItemTree crawlerId={this.state.selectedCrawlerId}
          setSensor={this.setSensor.bind(this)} getSensor={this.getSensor.bind(this)} />
      </Segment>,
      <ETCSelector setSensor={this.setSensor.bind(this)} getSensor={this.getSensor.bind(this)} />];

    return (
      <SensorConfigStepperContainer steps={steps} infraId={this.props.infraId} infra={this.props.infra} infraList={this.props.infraList}
        setSensor={this.setSensor.bind(this)} getSensor={this.getSensor.bind(this)} />
    );
  }
}





export interface ETCSelectorProps {
  setSensor?(data: SensorRegistInfo): void;
  getSensor?(): SensorRegistInfo;
}

export interface ETCSelectorState {
  interval: string;
}

export class ETCSelector extends React.Component<ETCSelectorProps, ETCSelectorState> {
  constructor(props: any, context: any) {
    super(props, context);
    this.state = {
      interval: '5',
    };

    let sd = this.props.getSensor();
    sd.interval = 5;
    this.props.setSensor(sd);
  }
  public handleIntervalChange = (e: any, { value }: any) => {
    this.setState({ interval: value });

    let sd = this.props.getSensor();
    sd.interval = value;
    this.props.setSensor(sd);
  }

  public render(): JSX.Element {
    return (
      <Table celled={true}>
        <Table.Body>
          <Table.Row>
            <Table.Cell collapsing>
              Interval
            </Table.Cell>
            <Table.Cell>
              <Form.Group inline>
                <Form.Radio
                  label='5 seconds'
                  name='radioGroup'
                  value='5'
                  checked={this.state.interval === '5'}
                  onChange={this.handleIntervalChange}
                />
                <Form.Radio
                  label='10 seconds'
                  name='radioGroup'
                  value='10'
                  checked={this.state.interval === '10'}
                  onChange={this.handleIntervalChange}
                />
                <Form.Radio
                  label='15 seconds'
                  name='radioGroup'
                  value='15'
                  checked={this.state.interval === '15'}
                  onChange={this.handleIntervalChange}
                />
              </Form.Group>
            </Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              Notification
            </Table.Cell>
            <Table.Cell></Table.Cell>
          </Table.Row>
          <Table.Row>
            <Table.Cell collapsing>
              Warn Condition
            </Table.Cell>
            <Table.Cell></Table.Cell>
          </Table.Row>
        </Table.Body>
      </Table>
    );
  }
}
