import * as React from 'react';
import { Table, Button, Header, Container } from 'semantic-ui-react';

import Sensor from '@overflow/sensor/api/model/Sensor';
import SensorItem from '@overflow/sensor/api/model/SensorItem';
import Page from '@overflow/commons/api/model/Page';
import { Pager } from '@overflow/commons/react/component/Pager';
import PageParams from '@overflow/commons/api/model/PageParams';
import { SortTableHeaderRow } from '@overflow/commons/react/component/SortTableHeaderRow';

export interface StateProps {
  sensorId?: number;
  sensorItemList?: Page;
}

export interface DispatchProps {
  onReadAllBySensor?(sensor: Sensor, pageParams: PageParams): void;
}

export type Props = StateProps & DispatchProps;

export interface State {

}


export class SensorDetailItems extends React.Component<Props, State> {

  private countPerPage: number = 10;
  private sortCol: string = 'id';
  private sortDirection: string = 'descending';
  private pageNo: number = 0;

  constructor(props: Props, context: State) {
    super(props, context);
    this.state = {
      // sensorItemList: SensorItemJson,
    };

    this.getData();
  }

  private getData(): void {
    const pageParams: PageParams = {
      pageNo: String(this.pageNo),
      countPerPage: String(this.countPerPage),
      sortCol: this.sortCol,
      sortDirection: this.sortDirection,
    };
    this.props.onReadAllBySensor({ id: this.props.sensorId }, pageParams);
  }

  public componentWillMount(): void {
    console.log('');
  }

  private handlePaging = (pageNo: number) => {
    this.pageNo = pageNo;
    const pageParams: PageParams = {
      pageNo: String(this.pageNo),
      countPerPage: String(this.countPerPage),
      sortCol: this.sortCol,
      sortDirection: this.sortDirection,
    };
    this.props.onReadAllBySensor({ id: this.props.sensorId }, pageParams);
  }

  public render(): JSX.Element {
    if (this.props.sensorItemList === undefined) {
      return null;
    }
    let colsmap: Map<string, string> = new Map();
    colsmap.set('No.', 'id');
    colsmap.set('Type', 'item.itemType.name');
    colsmap.set('Name', 'item.name');
    colsmap.set('Key', 'item.key');

    return (
      <Container fluid>
        <Table celled sortable>
          <Table.Header>
            <SortTableHeaderRow columnMap={colsmap} onHeaderColumnClick={this.handleSort} />
            {/* <Table.Row>
              <Table.HeaderCell>No.</Table.HeaderCell>
              <Table.HeaderCell>Type</Table.HeaderCell>
              <Table.HeaderCell>Name</Table.HeaderCell>
              <Table.HeaderCell>Key</Table.HeaderCell>
            </Table.Row> */}
          </Table.Header>

          <Table.Body>
            {
              this.props.sensorItemList.content ? this.props.sensorItemList.content.map((sensorItem: SensorItem, idx: number) => {
                return (
                  <Table.Row key={idx}>
                    <Table.Cell>{idx}</Table.Cell>
                    <Table.Cell>{sensorItem.item.itemType.name}</Table.Cell>
                    <Table.Cell>{sensorItem.item.name}</Table.Cell>
                    <Table.Cell>{sensorItem.item.key}</Table.Cell>
                  </Table.Row>
                );
              }) : ''
            }
          </Table.Body>
          <Table.Footer>
            <Table.Row>
              <Table.HeaderCell colSpan='4'>
                <Pager page={this.props.sensorItemList} onPageChange={this.handlePaging} />
              </Table.HeaderCell>
            </Table.Row>
          </Table.Footer>
        </Table>
      </Container>
    );
  }
  private handleSort = (col: string, direction: string): void => {
    console.log(col + ' || direction:' + direction);
    this.sortCol = col;
    this.sortDirection = direction;
    this.getData();
  }
}



// const SensorItemJson: any = [{
//   'id': 1,
//   'sensor': {
//     'id': 1,
//     'createDate': 1498475947009,
//     'description': 'My sensor',
//     'status': {
//       'id': 1,
//       'name': 'RUNNING',
//     },
//     'target': {
//       'id': 1,
//       'createDate': 1501154289555,
//       'displayName': 'ghost target',
//       'description': 'i am target',
//     },
//     'crawler': {
//       'id': 1,
//       'createDate': 1498794968791,
//       'name': 'ACTIVEDIRECTORY_CRAWLER',
//       'description': 'ACTIVEDIRECTORY',
//     },
//     'crawlerInputItems': null,
//   },
//   'item': {
//     'id': 1,
//     'itemType': {
//       'id': 1,
//       'name': 'CPU',
//       'description': 'CPU blah blah blah',
//       'createDate': 1498474179690,
//     },
//     'key': 'cpu.usage',
//     'name': 'CPU USAGE',
//     'createDate': 1498475408269,
//   },
//   'createDate': 1498476076626,
// },
// {
//   'id': 2,
//   'sensor': {
//     'id': 1,
//     'createDate': 1498475947074,
//     'description': 'My sensor',
//     'status': {
//       'id': 1,
//       'name': 'RUNNING',
//     },
//     'target': {
//       'id': 1,
//       'createDate': 1501154289555,
//       'displayName': 'ghost target',
//       'description': 'i am target',
//     },
//     'crawler': {
//       'id': 1,
//       'createDate': 1498794968791,
//       'name': 'ACTIVEDIRECTORY_CRAWLER',
//       'description': 'ACTIVEDIRECTORY',
//     },
//     'crawlerInputItems': null,
//   },
//   'item': {
//     'id': 2,
//     'itemType': {
//       'id': 1,
//       'name': 'CPU',
//       'description': 'CPU blah blah blah',
//       'createDate': 1498474179690,
//     },
//     'key': 'cpu.free',
//     'name': 'CPU FREE',
//     'createDate': 1498475408361,
//   },
//   'createDate': 1498476110988,
// },
// ];
