import { connect, Dispatch } from 'react-redux';
import {
  TargetList,
  StateProps as StateProps,
  DispatchProps as DispatchProps,
} from './components/TargetList';

import Probe from '@overflow/probe/api/model/Probe';
import Domain from '@overflow/domain/api/model/Domain';
import * as targetListActions from '../redux/action/read_all_by_probe';
import { push as routerPush } from 'react-router-redux';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';
import PageParams from '@overflow/commons/api/model/PageParams';


export function mapStateToProps(state: any, props: any): StateProps {
  return {
    probeId: props.params.id,
    infraList: state.infraList,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>): DispatchProps {
  return {
    onReadAllByProbe: (probe: Probe, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('InfraService', 'readAllByProbe', targetListActions.REQUEST,
                                           JSON.stringify(probe), JSON.stringify(pageParams)));
    },
    onReadAllByDomain: (domain: Domain, pageParams: PageParams) => {
      dispatch(asyncRequestActions.request('InfraService', 'readAllByDomain', targetListActions.REQUEST,
                                           JSON.stringify(domain), JSON.stringify(pageParams)));
    },
    onTargetSelection: (infraId: string) => {
      dispatch(routerPush('/target/' + infraId));
    },
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(TargetList);
